@@ -3,12 +3,17 @@ descStat= function(df,CONF=.95,rnd=3)
 # function to compute descriptive stats
 pandterm = function(message) {
         stop(message, call. = FALSE) }
-if (missing(df)) pandterm("Requires a dataframe")
-if (!is.data.frame(df)) pandterm("Input not a dataframe - try data.frame(input)")
+if (missing(df)) pandterm("Requires a dataframe,matrix, or vector as input")
+if (!is.data.frame(df)){
+ 	if(!is.matrix(df) & !is.vector(df))
+		{pandterm("Input not a dataframe, matrix, or vector")}
+	else
+		{if(!is.data.frame(df)) df=data.frame(df)}
+}
 if(!is.numeric(CONF)) pandterm("Confidence must be numeric variable")
 if(!(CONF < 1 & CONF >0)) pandterm("Confidence must be in (0,1)")
 numeric=sapply(df,is.numeric)
-dfn=df[,numeric]
+dfn=df[,numeric,drop=FALSE]
 numNA=function(vec){sum(is.na(vec))}
 nmiss=sapply(dfn,numNA)
 means=sapply(dfn,mean,na.rm=TRUE)
